fnss.topologies.topology.Topology.add_path — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.Topology.add_path

`Topology.` `add_path`(nodes, **attr)

  Add a path.

  Parameters : | nodes : iterable container A container of nodes. A path will be constructed from the nodes (in order) and added to the graph. attr : keyword arguments, optional (default= no attributes) Attributes to add to every edge in path.

  See also

  `add_star`, `add_cycle`

  Examples

      >>> G=nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.add_path([10,11,12],weight=7)

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »